@@ -117,7 +117,10 @@ VideoWidget::VideoWidget(MaemoBarcodeWindow *parent, BarcodeDetector *decoder) :
     frametime.start();
     timerOpenGL = new QTimer(this);
     QObject::connect(timerOpenGL, SIGNAL(timeout()), this, SLOT(updateGL()));
-    timerOpenGL->setInterval(PAINTGL_INTERVAL_HIGH); //update the window every x milliseconds
+    if(parent->isLensCoverOpen())
+        timerOpenGL->setInterval(PAINTGL_INTERVAL_HIGH); //update the window every x milliseconds
+    else
+        timerOpenGL->setInterval(PAINTGL_INTERVAL_LOW); //update the window every x milliseconds
     timerOpenGL->start();
     qDebug() << "VideoWidget::VideoWidget(): Finished";
 }
@@ -420,7 +423,7 @@ void VideoWidget::start(bool evenIfNotYetStarted) {
         //    refocus();
         if(parent->settings->value("use_autofocus", true).toBool()) {
             refocusTimer->start();
-        }
+        }        
         keepRunning = true;
         timerOpenGL->setInterval(PAINTGL_INTERVAL_HIGH);
     }
